from setuptools import setup

setup(name='startour_iq_lib',
      version='0.5',
      description= 'stars are good',
      author='Divyanshi',
      packages=['startour_iq_lib'],
      zip_safe=False)
